@@ -6,6 +6,7 @@ module HTMLProofer
 
     class InvalidHtmlError < StandardError
       def initialize(failures)
+        super
         @failures = failures
       end
 
@@ -21,7 +22,8 @@ module HTMLProofer
         allow_hash_href: true,
         check_external_hash: true,
         check_html: true,
-        url_ignore: [/.*/] # Don't try to check local files exist
+        url_ignore: [%r{^/}], # Don't try to check if local files exist
+        validation: { report_eof_tags: true }
       }
     end
 
@@ -52,13 +54,13 @@ module HTMLProofer
     def call(env)
       result = @app.call(env)
       return result if env['REQUEST_METHOD'] != 'GET'
-      return result if env['QUERY_STRING'] =~ /proofer-ignore/
+      return result if /proofer-ignore/.match?(env['QUERY_STRING'])
       return result if result.first != 200
 
       body = []
       result.last.each { |e| body << e }
 
-      body = body.join('')
+      body = body.join
       begin
         html = body.lstrip
       rescue StandardError
@@ -69,7 +71,7 @@ module HTMLProofer
           'response',
           Middleware.options
         ).check_parsed(
-          Nokogiri::HTML(clean_content(html)), 'response'
+          Nokogiri::HTML5(html, max_errors: -1), 'response'
         )
 
         raise InvalidHtmlError, parsed[:failures] unless parsed[:failures].empty?
