@@ -200,6 +200,12 @@ describe 'Links test' do
     expect(proofer.failed_tests).to eq []
   end
 
+  it 'ignores blank mailto links when configured to allow them' do
+    blank_mail_to_link = "#{FIXTURES_DIR}/links/blank_mailto_link.html"
+    proofer = run_proofer(blank_mail_to_link, :file, ignore_empty_mailto: true)
+    expect(proofer.failed_tests).to eq []
+  end
+
   it 'fails for blank mailto links' do
     blank_mail_to_link = "#{FIXTURES_DIR}/links/blank_mailto_link.html"
     proofer = run_proofer(blank_mail_to_link, :file)
